unit TiePieDLL;
{* DESCRIPTION
 *   This unit contains all definitions and declarations that are required
 *   to use a TiePie instrument in a Delphi application.
 *   This is a universal unit, therefor it may contain definitions and declarations
 *   that are not supported by the instrument you are writing software for.
 *   Using these will be handled properly by the dll and should not cause problems
 * NOTE
 *   Despite the care taken to generate the dll's and the accomanying files,
 *   TiePie engineering can not be held responsible for any damage as a result of using
 *   the dll's and the accompanying source files.
 * COPYRIGHT
 *   TiePie engineering
 *}
interface

uses
  Windows, Classes;


const
// Return codes = bit values. Non-zero is an error:
  E_NO_ERRORS            = $0000;
  E_NO_HARDWARE          = $0001;
  E_NOT_INITIALIZED      = $0002;
  E_NOT_SUPPORTED        = $0004;
  E_NO_GENERATOR         = $0008;
  E_INVALID_CHANNEL      = $0010;
  E_INVALID_VALUE        = $0020;
  E_I2C_ERROR            = $0040;
  E_I2C_INVALID_ADDRESS  = $0080;
  E_I2C_INVALID_SIZE     = $0100;
  E_I2C_NO_ACKNOWLEDGE   = $0200;

// Channel constants:
  lCh1                   =  1;
  lCh2                   =  2;
  lCh3                   =  3;
  lCh4                   =  4;

// Measure Mode constants, do NOT use for anything else than G/SetMeasureMode().
// When measuring more channels, simply add the required constants together : e.g. mmCh1 + mmCh2 to measure both Ch1 and Ch2
  mmCh1                  =  1;
  mmCh2                  =  2;
  mmCh3                  =  4;
  mmCh4                  =  8;
  mmCh12                 =  3;

// Coupling constants:
  lctAC                  =  0;
  lctDC                  =  1;

// Trigger mode constants:
  ltkRising              =  0; // Trigger when signal passes level in positive direction
  ltkFalling             =  1; // Trigger when signal passes level in negative direction
  ltkInWindow            =  2; // Trigger when signal enters marked window
  ltkOutWindow           =  3; // Trigger when signal leaves marked window
  ltkTVLine              =  4; // Trigger at TV line sync pulse
  ltkTVFieldOdd          =  5; // Trigger at Odd TV field sync pulse
  ltkTVFieldEven         =  6; // Trigger at Even TV field sync pulse
  ltkNet                 =  7; // Trigger on peaks/dips in the line net
  ltkNthPulse            =  8; // Trigger on the nth pulse after start of measuring
  ltkPulseLargerM        =  9; // Trigger if a pulse is larger than M
  ltkPulseSmallerM       = 10; // Trigger if a pulse is smaller than M
  ltkGlitch              = 11; // Trigger when the change between two samples is larger than x

// Trigger source constants:
  ltsCh1                 =  0; // Trigger on Ch1
  ltsCh2                 =  1; // Trigger on Ch2
  ltsCh3                 =  2; // Trigger on Ch3
  ltsCh4                 =  3; // Trigger on Ch4
  ltsExternal            =  4; // Trigger on digital external trigger input
  ltsAnalogExt           =  5; // Trigger on analog external trigger input
  ltsAnd                 =  6; // Trigger on Ch1 AND Ch2
  ltsOr                  =  7; // Trigger on Ch1 OR  Ch2
  ltsXor                 =  8; // Trigger on Ch1 XOR Ch2
  ltsNoTrig              =  9; // Do not wait for trigger, measure immediately
  ltsNeverTrig           = 10; // not used
  ltsPxiExt              = 11; // Trigger on external PXI trigger inputs
  ltsGenStart            = 12; // Trigger on Generator Start Signal
  ltsGenStop             = 13; // Trigger on Generator Stop Signal
  ltsGenNew              = 14; // Trigger on Generator New Period
  ltsUnknown             = 15; // not used

// Transfer mode constants:
  ltmBlock               =  0;
  ltmStream              =  1;

// Instrument Configuration constants:
  licHS3Norm             =  0;
  licHS3256K             =  1;
  licHS3512K             =  2;

// FuncGen Modes:
  lfmDDS                 =  1;
  lfmLinear              =  2;

// Signal types
  lstSine                =  0;
  lstTriangle            =  1;
  lstSquare              =  2;
  lstDC                  =  3;
  lstNoise               =  4;
  lstArbitrary           =  5;



type
  ERROR             = word;
  DArray            = array[0 .. 512 * 1024] of double;
  PDArray           = ^DArray;
  PDouble           = ^Double;
  Pbyte             = ^byte;
  PWord             = ^word;
  PDword            = ^dword;
  TWArray           = array [0 .. 512 * 1024] of word;
  TWArray2          = array [0 .. 512 * 1024] of word;
  PTWArray          = ^TWArray;
  PTDarray          = ^DArray;
  TInfoArray        = array[0 .. 19] of double;
  PInfoArray        = ^TInfoArray;
  TDataReady        = procedure; stdcall;
 {*
  * Function prototypes
  *}

// Open / Close the instrument:
  TInitInstrument = function( wAddress : Word ) : ERROR; stdcall;
  TExitInstrument = function : ERROR; stdcall;
 
// Get information about the instrument:
  TGetCalibrationDate = function( dwDate : PDWORD ) : ERROR; stdcall;
  TGetSerialNumber = function( dwSerialNumber : PDWORD ) : ERROR; stdcall;
  TGetAvailableSensitivities = function( dSensitivities : PInfoArray ) : ERROR; stdcall;
  TGetAvailableResolutions = function( dResolutions : PInfoArray ) : ERROR; stdcall;
  TGetNrChannels = function( wValue : PWord ) : ERROR; stdcall;
  TGetMaxSampleFrequencyF = function : Double; stdcall;
  TGetMaxRecordLength = function : DWORD; stdcall;
  TGetDCLevelStatus = function : DWORD; stdcall;
 
// Measurement routines:
  TADC_Start = function : ERROR; stdcall;
  TADC_Running = function : Word; stdcall;
  TADC_Abort = function : ERROR; stdcall;
  TADC_ForceTrig = function : ERROR; stdcall;
  TADC_Triggered = function : Word; stdcall;
  TADC_Ready = function : Word; stdcall;
 
// Retrieve the measured data:
  TADC_GetDataCh = function( wCh : Word ; wChData : PTWArray ) : ERROR; stdcall;
  TADC_GetDataVoltCh = function( wCh : Word ; dChData : PTDArray ) : ERROR; stdcall;
  TGetDigitalInputValues = function( wValues : PTWArray ) : ERROR; stdcall;
  TGetOneDigitalValue = function( dwIndex : DWORD ; wValue : PWord ) : ERROR; stdcall;
 
// Streaming measurements:
  TSetDataReadyCallback = function( pAddress : TDataReady ) : ERROR; stdcall;
  TSetDataReadyEvent = function( hEvent : THandle ) : ERROR; stdcall;
  TSetTransferMode = function( dwMode : DWORD ) : ERROR; stdcall;
  TGetTransferMode = function( dwMode : PDWORD ) : ERROR; stdcall;
 
// Control the input resolution in bits:
  TSetResolution = function( byValue : Byte ) : ERROR; stdcall;
  TGetResolution = function( byValue : PByte ) : ERROR; stdcall;
 
// Control the instrument configuration:
  TSetInstrumentConfig = function( wMode : Word ) : ERROR; stdcall;
  TGetInstrumentConfig = function( wMode : PWord ) : ERROR; stdcall;
 
// Control which channels are measured:
  TGetMeasureMode = function( byMode : PByte ) : ERROR; stdcall;
  TSetMeasureMode = function( byMode : Byte ) : ERROR; stdcall;
 
// Control the time base:
  TGetRecordLength = function : DWORD; stdcall;
  TSetRecordLength = function( dwRecordLength : DWORD ) : ERROR; stdcall;
  TGetPostSamples = function : DWORD; stdcall;
  TSetPostSamples = function( dwPostSampleCount : DWORD ) : ERROR; stdcall;
  TGetSampleFrequencyF = function : Double; stdcall;
  TSetSampleFrequencyF = function( dFreq : PDouble ) : ERROR; stdcall;
  TGetExternalClock = function( wMode : PWord ) : ERROR; stdcall;
  TSetExternalClock = function( wMode : Word ) : ERROR; stdcall;
 
// Control the analog input channels:
  TGetSensitivity = function( byCh : Byte ; dSensitivity : PDouble ) : ERROR; stdcall;
  TSetSensitivity = function( byCh : Byte ; dSensitivity : PDouble ) : ERROR; stdcall;
  TGetAutoRanging = function( byCh : Byte ; byMode : PByte ) : ERROR; stdcall;
  TSetAutoRanging = function( byCh : Byte ; byMode : Byte ) : ERROR; stdcall;
  TGetCoupling = function( byCh : Byte ; byMode : PByte ) : ERROR; stdcall;
  TSetCoupling = function( byCh : Byte ; byMode : Byte ) : ERROR; stdcall;
  TGetDcLevel = function( byCh : Byte ; dDcLevel : PDouble ) : ERROR; stdcall;
  TSetDcLevel = function( byCh : Byte ; dDcLevel : Double ) : ERROR; stdcall;
 
// Control the trigger system:
  TGetTriggerSource = function( byTrigSource : PByte ) : ERROR; stdcall;
  TSetTriggerSource = function( byTrigSource : Byte ) : ERROR; stdcall;
  TGetTriggerMode = function( byMode : PByte ) : ERROR; stdcall;
  TSetTriggerMode = function( byMode : Byte ) : ERROR; stdcall;
  TGetTriggerModeCh = function( byCh : Byte ; byMode : PByte ) : ERROR; stdcall;
  TSetTriggerModeCh = function( byCh : Byte ; byMode : Byte ) : ERROR; stdcall;
  TGetTriggerLevel = function( byCh : Byte ; dLevel : PDouble ) : ERROR; stdcall;
  TSetTriggerLevel = function( byCh : Byte ; dLevel : Double ) : ERROR; stdcall;
  TGetTriggerHys = function( byCh : Byte ; dHysteresis : PDouble ) : ERROR; stdcall;
  TSetTriggerHys = function( byCh : Byte ; dHysteresis : Double ) : ERROR; stdcall;
  TGetPXITriggerEnables = function( byEnables : PByte ) : ERROR; stdcall;
  TSetPXITriggerEnables = function( byEnables : Byte ) : ERROR; stdcall;
  TGetPXITriggerSlopes = function( bySlopes : PByte ) : ERROR; stdcall;
  TSetPXITriggerSlopes = function( bySlopes : Byte ) : ERROR; stdcall;
 
// Control the digital outputs:
  TSetDigitalOutputs = function( byValue : Byte ) : ERROR; stdcall;
  TGetDigitalOutputs = function( byValue : PByte ) : ERROR; stdcall;
 
// Square Wave Generator:
  TGetSquareWaveGenStatus = function : ERROR; stdcall;
  TGetSquareWaveGenFrequency = function : DWORD; stdcall;
  TSetSquareWaveGenFrequency = function( dwFreq : PDWORD ) : ERROR; stdcall;
 
// Get information about the function generator:
  TGetFunctionGenStatus = function : ERROR; stdcall;
  TGetFuncGenMaxAmplitude = function( dMaxAmplitude : PDouble ) : ERROR; stdcall;
 
// Control the Arbitrary Waveform Generator:
  TGetFuncGenOutputOn = function( wValue : PWord ) : ERROR; stdcall;
  TSetFuncGenOutputOn = function( wValue : Word ) : ERROR; stdcall;
  TGetFuncGenEnable = function( wValue : PWord ) : ERROR; stdcall;
  TSetFuncGenEnable = function( wValue : Word ) : ERROR; stdcall;
  TGetFuncGenSignalType = function( wValue : PWord ) : ERROR; stdcall;
  TSetFuncGenSignalType = function( wValue : Word ) : ERROR; stdcall;
  TSetFuncGenMode = function( dwMode : DWORD ) : ERROR; stdcall;
  TGetFuncGenMode = function( dwMode : PDWORD ) : ERROR; stdcall;
  TGetFuncGenAmplitude = function( dValue : PDouble ) : ERROR; stdcall;
  TSetFuncGenAmplitude = function( dValue : Double ) : ERROR; stdcall;
  TGetFuncGenAmplitudeRange = function( byValue : PByte ) : ERROR; stdcall;
  TSetFuncGenAmplitudeRange = function( byValue : Byte ) : ERROR; stdcall;
  TGetFuncGenDCOffset = function( dValue : PDouble ) : ERROR; stdcall;
  TSetFuncGenDCOffset = function( dValue : Double ) : ERROR; stdcall;
  TGetFuncGenSymmetry = function( dValue : PDouble ) : ERROR; stdcall;
  TSetFuncGenSymmetry = function( dValue : Double ) : ERROR; stdcall;
  TGetFuncGenFrequency = function( dValue : PDouble ) : ERROR; stdcall;
  TSetFuncGenFrequency = function( dValue : PDouble ) : ERROR; stdcall;
  TSetFuncGenTrigSource = function( byTrigSource : Byte ) : ERROR; stdcall;
  TGetFuncGenTrigSource = function( byTrigSource : PByte ) : ERROR; stdcall;
  TFillFuncGenMemory = function( dwSampleCount : DWORD ; FuncGenData : PTWArray ) : ERROR; stdcall;
  TFuncGenBurst = function( wNrPeriods : Word ) : ERROR; stdcall;
 
// Ohm measurements ( not available by default ):
  TSetupOhmMeasurements = function( wMode : Word ) : ERROR; stdcall;
  TGetOhmValues = function( dValue1 : PDouble ; dValue2 : PDouble ) : ERROR; stdcall;
 
// I2C routines:
  TI2CWrite = function( dwAddress : DWORD ; pBuf : pointer ; dwSize : DWORD ) : ERROR; stdcall;
  TI2CWriteNoStop = function( dwAddress : DWORD ; pBuf : pointer ; dwSize : DWORD ) : ERROR; stdcall;
  TI2CRead = function( dwAddress : DWORD ; pBuf : pointer ; dwSize : DWORD ) : ERROR; stdcall;
  TI2CReadNoStop = function( dwAddress : DWORD ; pBuf : pointer ; dwSize : DWORD ) : ERROR; stdcall;
  TI2CGetSpeed = function( dwSpeed : PDWORD ) : ERROR; stdcall;
  TI2CSetSpeed = function( dwSpeed : PDWORD ) : ERROR; stdcall;
 
// Handyscope HS2 Only:
  TGetActiveHS2 = function( byActiveHS2 : PByte ) : ERROR; stdcall;
  TSetActiveHS2 = function( byActiveHS2 : Byte ) : ERROR; stdcall;
  TSetDAC1451 = function( dMotor1 : Double ; dMotor2 : Double ) : ERROR; stdcall;
  TSetMotorOn = function( byMotor1 : Byte ; byMotor2 : Byte ) : ERROR; stdcall;
 
// Obsolete routines, use is deprecated:
  TGetMaxSampleFrequency = function : DWORD; stdcall;
  TStartMeasurement = function : ERROR; stdcall;
  TGetMeasurement = function( dCh1 : PTDArray ; dCh2 : PTDArray ) : ERROR; stdcall;
  TGetMeasurementRaw = function( wCh1 : PTWArray ; wCh2 : PTWArray ) : ERROR; stdcall;
  TGetOneMeasurement = function( dwIndex : DWORD ; dCh1 : PDouble ; dCh2 : PDouble ) : ERROR; stdcall;
  TGetOneMeasurementRaw = function( dwIndex : DWORD ; wCh1 : PWord ; wCh2 : PWord ) : ERROR; stdcall;
  TGetOneMeasurementRawCh = function( wCh : Word ; dwIndex : DWORD ; wChData : PWord ) : ERROR; stdcall;
  TADC_GetData = function( wCh1 : PTWArray ; wCh2 : PTWArray ) : ERROR; stdcall;
  TADC_GetDataVolt = function( dCh1 : PTDArray ; dCh2 : PTDArray ) : ERROR; stdcall;
  TGetSampleFrequency = function : DWORD; stdcall;
  TSetSampleFrequency = function( dwFreq : PDWORD ) : ERROR; stdcall;
  TGetTriggerTimeOut = function : DWORD; stdcall;
  TSetTriggerTimeOut = function( dwTimeout : DWORD ) : ERROR; stdcall;



  // Instrument class:

  TTiePieInstrument = class( TComponent )
  protected
    // Internal:
    FDllHandle         : THandle;

    // Pointers to DLL routines:
// Open / Close the instrument:
    FInitInstrument : TInitInstrument;
    FExitInstrument : TExitInstrument;
 
// Get information about the instrument:
    FGetCalibrationDate : TGetCalibrationDate;
    FGetSerialNumber : TGetSerialNumber;
    FGetAvailableSensitivities : TGetAvailableSensitivities;
    FGetAvailableResolutions : TGetAvailableResolutions;
    FGetNrChannels : TGetNrChannels;
    FGetMaxSampleFrequencyF : TGetMaxSampleFrequencyF;
    FGetMaxRecordLength : TGetMaxRecordLength;
    FGetDCLevelStatus : TGetDCLevelStatus;
 
// Measurement routines:
    FADC_Start : TADC_Start;
    FADC_Running : TADC_Running;
    FADC_Abort : TADC_Abort;
    FADC_ForceTrig : TADC_ForceTrig;
    FADC_Triggered : TADC_Triggered;
    FADC_Ready : TADC_Ready;
 
// Retrieve the measured data:
    FADC_GetDataCh : TADC_GetDataCh;
    FADC_GetDataVoltCh : TADC_GetDataVoltCh;
    FGetDigitalInputValues : TGetDigitalInputValues;
    FGetOneDigitalValue : TGetOneDigitalValue;
 
// Streaming measurements:
    FSetDataReadyCallback : TSetDataReadyCallback;
    FSetDataReadyEvent : TSetDataReadyEvent;
    FSetTransferMode : TSetTransferMode;
    FGetTransferMode : TGetTransferMode;
 
// Control the input resolution in bits:
    FSetResolution : TSetResolution;
    FGetResolution : TGetResolution;
 
// Control the instrument configuration:
    FSetInstrumentConfig : TSetInstrumentConfig;
    FGetInstrumentConfig : TGetInstrumentConfig;
 
// Control which channels are measured:
    FGetMeasureMode : TGetMeasureMode;
    FSetMeasureMode : TSetMeasureMode;
 
// Control the time base:
    FGetRecordLength : TGetRecordLength;
    FSetRecordLength : TSetRecordLength;
    FGetPostSamples : TGetPostSamples;
    FSetPostSamples : TSetPostSamples;
    FGetSampleFrequencyF : TGetSampleFrequencyF;
    FSetSampleFrequencyF : TSetSampleFrequencyF;
    FGetExternalClock : TGetExternalClock;
    FSetExternalClock : TSetExternalClock;
 
// Control the analog input channels:
    FGetSensitivity : TGetSensitivity;
    FSetSensitivity : TSetSensitivity;
    FGetAutoRanging : TGetAutoRanging;
    FSetAutoRanging : TSetAutoRanging;
    FGetCoupling : TGetCoupling;
    FSetCoupling : TSetCoupling;
    FGetDcLevel : TGetDcLevel;
    FSetDcLevel : TSetDcLevel;
 
// Control the trigger system:
    FGetTriggerSource : TGetTriggerSource;
    FSetTriggerSource : TSetTriggerSource;
    FGetTriggerMode : TGetTriggerMode;
    FSetTriggerMode : TSetTriggerMode;
    FGetTriggerModeCh : TGetTriggerModeCh;
    FSetTriggerModeCh : TSetTriggerModeCh;
    FGetTriggerLevel : TGetTriggerLevel;
    FSetTriggerLevel : TSetTriggerLevel;
    FGetTriggerHys : TGetTriggerHys;
    FSetTriggerHys : TSetTriggerHys;
    FGetPXITriggerEnables : TGetPXITriggerEnables;
    FSetPXITriggerEnables : TSetPXITriggerEnables;
    FGetPXITriggerSlopes : TGetPXITriggerSlopes;
    FSetPXITriggerSlopes : TSetPXITriggerSlopes;
 
// Control the digital outputs:
    FSetDigitalOutputs : TSetDigitalOutputs;
    FGetDigitalOutputs : TGetDigitalOutputs;
 
// Square Wave Generator:
    FGetSquareWaveGenStatus : TGetSquareWaveGenStatus;
    FGetSquareWaveGenFrequency : TGetSquareWaveGenFrequency;
    FSetSquareWaveGenFrequency : TSetSquareWaveGenFrequency;
 
// Get information about the function generator:
    FGetFunctionGenStatus : TGetFunctionGenStatus;
    FGetFuncGenMaxAmplitude : TGetFuncGenMaxAmplitude;
 
// Control the Arbitrary Waveform Generator:
    FGetFuncGenOutputOn : TGetFuncGenOutputOn;
    FSetFuncGenOutputOn : TSetFuncGenOutputOn;
    FGetFuncGenEnable : TGetFuncGenEnable;
    FSetFuncGenEnable : TSetFuncGenEnable;
    FGetFuncGenSignalType : TGetFuncGenSignalType;
    FSetFuncGenSignalType : TSetFuncGenSignalType;
    FSetFuncGenMode : TSetFuncGenMode;
    FGetFuncGenMode : TGetFuncGenMode;
    FGetFuncGenAmplitude : TGetFuncGenAmplitude;
    FSetFuncGenAmplitude : TSetFuncGenAmplitude;
    FGetFuncGenAmplitudeRange : TGetFuncGenAmplitudeRange;
    FSetFuncGenAmplitudeRange : TSetFuncGenAmplitudeRange;
    FGetFuncGenDCOffset : TGetFuncGenDCOffset;
    FSetFuncGenDCOffset : TSetFuncGenDCOffset;
    FGetFuncGenSymmetry : TGetFuncGenSymmetry;
    FSetFuncGenSymmetry : TSetFuncGenSymmetry;
    FGetFuncGenFrequency : TGetFuncGenFrequency;
    FSetFuncGenFrequency : TSetFuncGenFrequency;
    FSetFuncGenTrigSource : TSetFuncGenTrigSource;
    FGetFuncGenTrigSource : TGetFuncGenTrigSource;
    FFillFuncGenMemory : TFillFuncGenMemory;
    FFuncGenBurst : TFuncGenBurst;
 
// Ohm measurements ( not available by default ):
    FSetupOhmMeasurements : TSetupOhmMeasurements;
    FGetOhmValues : TGetOhmValues;
 
// I2C routines:
    FI2CWrite : TI2CWrite;
    FI2CWriteNoStop : TI2CWriteNoStop;
    FI2CRead : TI2CRead;
    FI2CReadNoStop : TI2CReadNoStop;
    FI2CGetSpeed : TI2CGetSpeed;
    FI2CSetSpeed : TI2CSetSpeed;
 
// Handyscope HS2 Only:
    FGetActiveHS2 : TGetActiveHS2;
    FSetActiveHS2 : TSetActiveHS2;
    FSetDAC1451 : TSetDAC1451;
    FSetMotorOn : TSetMotorOn;
 
// Obsolete routines, use is deprecated:
    FGetMaxSampleFrequency : TGetMaxSampleFrequency;
    FStartMeasurement : TStartMeasurement;
    FGetMeasurement : TGetMeasurement;
    FGetMeasurementRaw : TGetMeasurementRaw;
    FGetOneMeasurement : TGetOneMeasurement;
    FGetOneMeasurementRaw : TGetOneMeasurementRaw;
    FGetOneMeasurementRawCh : TGetOneMeasurementRawCh;
    FADC_GetData : TADC_GetData;
    FADC_GetDataVolt : TADC_GetDataVolt;
    FGetSampleFrequency : TGetSampleFrequency;
    FSetSampleFrequency : TSetSampleFrequency;
    FGetTriggerTimeOut : TGetTriggerTimeOut;
    FSetTriggerTimeOut : TSetTriggerTimeOut;


    procedure RetrieveAllProcAddresses;
  public
    destructor Destroy; override;

    function OpenDLL( const sPath : string ) : boolean;

    // Routines routed to the DLL:
// Open / Close the instrument:
    function InitInstrument( wAddress : Word ) : ERROR;
    function ExitInstrument : ERROR;
 
// Get information about the instrument:
    function GetCalibrationDate( dwDate : PDWORD ) : ERROR;
    function GetSerialNumber( dwSerialNumber : PDWORD ) : ERROR;
    function GetAvailableSensitivities( dSensitivities : PInfoArray ) : ERROR;
    function GetAvailableResolutions( dResolutions : PInfoArray ) : ERROR;
    function GetNrChannels( wValue : PWord ) : ERROR;
    function GetMaxSampleFrequencyF : Double;
    function GetMaxRecordLength : DWORD;
    function GetDCLevelStatus : DWORD;
 
// Measurement routines:
    function ADC_Start : ERROR;
    function ADC_Running : Word;
    function ADC_Abort : ERROR;
    function ADC_ForceTrig : ERROR;
    function ADC_Triggered : Word;
    function ADC_Ready : Word;
 
// Retrieve the measured data:
    function ADC_GetDataCh( wCh : Word ; wChData : PTWArray ) : ERROR;
    function ADC_GetDataVoltCh( wCh : Word ; dChData : PTDArray ) : ERROR;
    function GetDigitalInputValues( wValues : PTWArray ) : ERROR;
    function GetOneDigitalValue( dwIndex : DWORD ; wValue : PWord ) : ERROR;
 
// Streaming measurements:
    function SetDataReadyCallback( pAddress : TDataReady ) : ERROR;
    function SetDataReadyEvent( hEvent : THandle ) : ERROR;
    function SetTransferMode( dwMode : DWORD ) : ERROR;
    function GetTransferMode( dwMode : PDWORD ) : ERROR;
 
// Control the input resolution in bits:
    function SetResolution( byValue : Byte ) : ERROR;
    function GetResolution( byValue : PByte ) : ERROR;
 
// Control the instrument configuration:
    function SetInstrumentConfig( wMode : Word ) : ERROR;
    function GetInstrumentConfig( wMode : PWord ) : ERROR;
 
// Control which channels are measured:
    function GetMeasureMode( byMode : PByte ) : ERROR;
    function SetMeasureMode( byMode : Byte ) : ERROR;
 
// Control the time base:
    function GetRecordLength : DWORD;
    function SetRecordLength( dwRecordLength : DWORD ) : ERROR;
    function GetPostSamples : DWORD;
    function SetPostSamples( dwPostSampleCount : DWORD ) : ERROR;
    function GetSampleFrequencyF : Double;
    function SetSampleFrequencyF( dFreq : PDouble ) : ERROR;
    function GetExternalClock( wMode : PWord ) : ERROR;
    function SetExternalClock( wMode : Word ) : ERROR;
 
// Control the analog input channels:
    function GetSensitivity( byCh : Byte ; dSensitivity : PDouble ) : ERROR;
    function SetSensitivity( byCh : Byte ; dSensitivity : PDouble ) : ERROR;
    function GetAutoRanging( byCh : Byte ; byMode : PByte ) : ERROR;
    function SetAutoRanging( byCh : Byte ; byMode : Byte ) : ERROR;
    function GetCoupling( byCh : Byte ; byMode : PByte ) : ERROR;
    function SetCoupling( byCh : Byte ; byMode : Byte ) : ERROR;
    function GetDcLevel( byCh : Byte ; dDcLevel : PDouble ) : ERROR;
    function SetDcLevel( byCh : Byte ; dDcLevel : Double ) : ERROR;
 
// Control the trigger system:
    function GetTriggerSource( byTrigSource : PByte ) : ERROR;
    function SetTriggerSource( byTrigSource : Byte ) : ERROR;
    function GetTriggerMode( byMode : PByte ) : ERROR;
    function SetTriggerMode( byMode : Byte ) : ERROR;
    function GetTriggerModeCh( byCh : Byte ; byMode : PByte ) : ERROR;
    function SetTriggerModeCh( byCh : Byte ; byMode : Byte ) : ERROR;
    function GetTriggerLevel( byCh : Byte ; dLevel : PDouble ) : ERROR;
    function SetTriggerLevel( byCh : Byte ; dLevel : Double ) : ERROR;
    function GetTriggerHys( byCh : Byte ; dHysteresis : PDouble ) : ERROR;
    function SetTriggerHys( byCh : Byte ; dHysteresis : Double ) : ERROR;
    function GetPXITriggerEnables( byEnables : PByte ) : ERROR;
    function SetPXITriggerEnables( byEnables : Byte ) : ERROR;
    function GetPXITriggerSlopes( bySlopes : PByte ) : ERROR;
    function SetPXITriggerSlopes( bySlopes : Byte ) : ERROR;
 
// Control the digital outputs:
    function SetDigitalOutputs( byValue : Byte ) : ERROR;
    function GetDigitalOutputs( byValue : PByte ) : ERROR;
 
// Square Wave Generator:
    function GetSquareWaveGenStatus : ERROR;
    function GetSquareWaveGenFrequency : DWORD;
    function SetSquareWaveGenFrequency( dwFreq : PDWORD ) : ERROR;
 
// Get information about the function generator:
    function GetFunctionGenStatus : ERROR;
    function GetFuncGenMaxAmplitude( dMaxAmplitude : PDouble ) : ERROR;
 
// Control the Arbitrary Waveform Generator:
    function GetFuncGenOutputOn( wValue : PWord ) : ERROR;
    function SetFuncGenOutputOn( wValue : Word ) : ERROR;
    function GetFuncGenEnable( wValue : PWord ) : ERROR;
    function SetFuncGenEnable( wValue : Word ) : ERROR;
    function GetFuncGenSignalType( wValue : PWord ) : ERROR;
    function SetFuncGenSignalType( wValue : Word ) : ERROR;
    function SetFuncGenMode( dwMode : DWORD ) : ERROR;
    function GetFuncGenMode( dwMode : PDWORD ) : ERROR;
    function GetFuncGenAmplitude( dValue : PDouble ) : ERROR;
    function SetFuncGenAmplitude( dValue : Double ) : ERROR;
    function GetFuncGenAmplitudeRange( byValue : PByte ) : ERROR;
    function SetFuncGenAmplitudeRange( byValue : Byte ) : ERROR;
    function GetFuncGenDCOffset( dValue : PDouble ) : ERROR;
    function SetFuncGenDCOffset( dValue : Double ) : ERROR;
    function GetFuncGenSymmetry( dValue : PDouble ) : ERROR;
    function SetFuncGenSymmetry( dValue : Double ) : ERROR;
    function GetFuncGenFrequency( dValue : PDouble ) : ERROR;
    function SetFuncGenFrequency( dValue : PDouble ) : ERROR;
    function SetFuncGenTrigSource( byTrigSource : Byte ) : ERROR;
    function GetFuncGenTrigSource( byTrigSource : PByte ) : ERROR;
    function FillFuncGenMemory( dwSampleCount : DWORD ; FuncGenData : PTWArray ) : ERROR;
    function FuncGenBurst( wNrPeriods : Word ) : ERROR;
 
// Ohm measurements ( not available by default ):
    function SetupOhmMeasurements( wMode : Word ) : ERROR;
    function GetOhmValues( dValue1 : PDouble ; dValue2 : PDouble ) : ERROR;
 
// I2C routines:
    function I2CWrite( dwAddress : DWORD ; pBuf : pointer ; dwSize : DWORD ) : ERROR;
    function I2CWriteNoStop( dwAddress : DWORD ; pBuf : pointer ; dwSize : DWORD ) : ERROR;
    function I2CRead( dwAddress : DWORD ; pBuf : pointer ; dwSize : DWORD ) : ERROR;
    function I2CReadNoStop( dwAddress : DWORD ; pBuf : pointer ; dwSize : DWORD ) : ERROR;
    function I2CGetSpeed( dwSpeed : PDWORD ) : ERROR;
    function I2CSetSpeed( dwSpeed : PDWORD ) : ERROR;
 
// Handyscope HS2 Only:
    function GetActiveHS2( byActiveHS2 : PByte ) : ERROR;
    function SetActiveHS2( byActiveHS2 : Byte ) : ERROR;
    function SetDAC1451( dMotor1 : Double ; dMotor2 : Double ) : ERROR;
    function SetMotorOn( byMotor1 : Byte ; byMotor2 : Byte ) : ERROR;
 
// Obsolete routines, use is deprecated:
    function GetMaxSampleFrequency : DWORD;
    function StartMeasurement : ERROR;
    function GetMeasurement( dCh1 : PTDArray ; dCh2 : PTDArray ) : ERROR;
    function GetMeasurementRaw( wCh1 : PTWArray ; wCh2 : PTWArray ) : ERROR;
    function GetOneMeasurement( dwIndex : DWORD ; dCh1 : PDouble ; dCh2 : PDouble ) : ERROR;
    function GetOneMeasurementRaw( dwIndex : DWORD ; wCh1 : PWord ; wCh2 : PWord ) : ERROR;
    function GetOneMeasurementRawCh( wCh : Word ; dwIndex : DWORD ; wChData : PWord ) : ERROR;
    function ADC_GetData( wCh1 : PTWArray ; wCh2 : PTWArray ) : ERROR;
    function ADC_GetDataVolt( dCh1 : PTDArray ; dCh2 : PTDArray ) : ERROR;
    function GetSampleFrequency : DWORD;
    function SetSampleFrequency( dwFreq : PDWORD ) : ERROR;
    function GetTriggerTimeOut : DWORD;
    function SetTriggerTimeOut( dwTimeout : DWORD ) : ERROR;

  end;


implementation

destructor TTiePieInstrument.Destroy;
begin
  Freelibrary( FDLLHandle );
  inherited;
end;

function TTiePieInstrument.OpenDLL( const sPath : string ) : boolean;
begin
  FDLLHandle := Loadlibrary( PChar( sPath ) );
  Result := FDLLHandle <> 0;
  if Result then
    RetrieveAllProcAddresses;
end;

procedure TTiePieInstrument.RetrieveAllProcAddresses;
{* DESCRIPTION
 *   This routine gets the procedure addresses of all routines in the dll
 *   It should be called after the dll has been loaded and the global variable
 *   DLLHandle points to the proper dll.
 * INPUT
 *   -
 * OUTPUT
 *   -
 *}
begin
// Open / Close the instrument:
  @FInitInstrument := GetProcAddress( FDLLHandle, 'InitInstrument' );
  @FExitInstrument := GetProcAddress( FDLLHandle, 'ExitInstrument' );
 
// Get information about the instrument:
  @FGetCalibrationDate := GetProcAddress( FDLLHandle, 'GetCalibrationDate' );
  @FGetSerialNumber := GetProcAddress( FDLLHandle, 'GetSerialNumber' );
  @FGetAvailableSensitivities := GetProcAddress( FDLLHandle, 'GetAvailableSensitivities' );
  @FGetAvailableResolutions := GetProcAddress( FDLLHandle, 'GetAvailableResolutions' );
  @FGetNrChannels := GetProcAddress( FDLLHandle, 'GetNrChannels' );
  @FGetMaxSampleFrequencyF := GetProcAddress( FDLLHandle, 'GetMaxSampleFrequencyF' );
  @FGetMaxRecordLength := GetProcAddress( FDLLHandle, 'GetMaxRecordLength' );
  @FGetDCLevelStatus := GetProcAddress( FDLLHandle, 'GetDCLevelStatus' );
 
// Measurement routines:
  @FADC_Start := GetProcAddress( FDLLHandle, 'ADC_Start' );
  @FADC_Running := GetProcAddress( FDLLHandle, 'ADC_Running' );
  @FADC_Abort := GetProcAddress( FDLLHandle, 'ADC_Abort' );
  @FADC_ForceTrig := GetProcAddress( FDLLHandle, 'ADC_ForceTrig' );
  @FADC_Triggered := GetProcAddress( FDLLHandle, 'ADC_Triggered' );
  @FADC_Ready := GetProcAddress( FDLLHandle, 'ADC_Ready' );
 
// Retrieve the measured data:
  @FADC_GetDataCh := GetProcAddress( FDLLHandle, 'ADC_GetDataCh' );
  @FADC_GetDataVoltCh := GetProcAddress( FDLLHandle, 'ADC_GetDataVoltCh' );
  @FGetDigitalInputValues := GetProcAddress( FDLLHandle, 'GetDigitalInputValues' );
  @FGetOneDigitalValue := GetProcAddress( FDLLHandle, 'GetOneDigitalValue' );
 
// Streaming measurements:
  @FSetDataReadyCallback := GetProcAddress( FDLLHandle, 'SetDataReadyCallback' );
  @FSetDataReadyEvent := GetProcAddress( FDLLHandle, 'SetDataReadyEvent' );
  @FSetTransferMode := GetProcAddress( FDLLHandle, 'SetTransferMode' );
  @FGetTransferMode := GetProcAddress( FDLLHandle, 'GetTransferMode' );
 
// Control the input resolution in bits:
  @FSetResolution := GetProcAddress( FDLLHandle, 'SetResolution' );
  @FGetResolution := GetProcAddress( FDLLHandle, 'GetResolution' );
 
// Control the instrument configuration:
  @FSetInstrumentConfig := GetProcAddress( FDLLHandle, 'SetInstrumentConfig' );
  @FGetInstrumentConfig := GetProcAddress( FDLLHandle, 'GetInstrumentConfig' );
 
// Control which channels are measured:
  @FGetMeasureMode := GetProcAddress( FDLLHandle, 'GetMeasureMode' );
  @FSetMeasureMode := GetProcAddress( FDLLHandle, 'SetMeasureMode' );
 
// Control the time base:
  @FGetRecordLength := GetProcAddress( FDLLHandle, 'GetRecordLength' );
  @FSetRecordLength := GetProcAddress( FDLLHandle, 'SetRecordLength' );
  @FGetPostSamples := GetProcAddress( FDLLHandle, 'GetPostSamples' );
  @FSetPostSamples := GetProcAddress( FDLLHandle, 'SetPostSamples' );
  @FGetSampleFrequencyF := GetProcAddress( FDLLHandle, 'GetSampleFrequencyF' );
  @FSetSampleFrequencyF := GetProcAddress( FDLLHandle, 'SetSampleFrequencyF' );
  @FGetExternalClock := GetProcAddress( FDLLHandle, 'GetExternalClock' );
  @FSetExternalClock := GetProcAddress( FDLLHandle, 'SetExternalClock' );
 
// Control the analog input channels:
  @FGetSensitivity := GetProcAddress( FDLLHandle, 'GetSensitivity' );
  @FSetSensitivity := GetProcAddress( FDLLHandle, 'SetSensitivity' );
  @FGetAutoRanging := GetProcAddress( FDLLHandle, 'GetAutoRanging' );
  @FSetAutoRanging := GetProcAddress( FDLLHandle, 'SetAutoRanging' );
  @FGetCoupling := GetProcAddress( FDLLHandle, 'GetCoupling' );
  @FSetCoupling := GetProcAddress( FDLLHandle, 'SetCoupling' );
  @FGetDcLevel := GetProcAddress( FDLLHandle, 'GetDcLevel' );
  @FSetDcLevel := GetProcAddress( FDLLHandle, 'SetDcLevel' );
 
// Control the trigger system:
  @FGetTriggerSource := GetProcAddress( FDLLHandle, 'GetTriggerSource' );
  @FSetTriggerSource := GetProcAddress( FDLLHandle, 'SetTriggerSource' );
  @FGetTriggerMode := GetProcAddress( FDLLHandle, 'GetTriggerMode' );
  @FSetTriggerMode := GetProcAddress( FDLLHandle, 'SetTriggerMode' );
  @FGetTriggerModeCh := GetProcAddress( FDLLHandle, 'GetTriggerModeCh' );
  @FSetTriggerModeCh := GetProcAddress( FDLLHandle, 'SetTriggerModeCh' );
  @FGetTriggerLevel := GetProcAddress( FDLLHandle, 'GetTriggerLevel' );
  @FSetTriggerLevel := GetProcAddress( FDLLHandle, 'SetTriggerLevel' );
  @FGetTriggerHys := GetProcAddress( FDLLHandle, 'GetTriggerHys' );
  @FSetTriggerHys := GetProcAddress( FDLLHandle, 'SetTriggerHys' );
  @FGetPXITriggerEnables := GetProcAddress( FDLLHandle, 'GetPXITriggerEnables' );
  @FSetPXITriggerEnables := GetProcAddress( FDLLHandle, 'SetPXITriggerEnables' );
  @FGetPXITriggerSlopes := GetProcAddress( FDLLHandle, 'GetPXITriggerSlopes' );
  @FSetPXITriggerSlopes := GetProcAddress( FDLLHandle, 'SetPXITriggerSlopes' );
 
// Control the digital outputs:
  @FSetDigitalOutputs := GetProcAddress( FDLLHandle, 'SetDigitalOutputs' );
  @FGetDigitalOutputs := GetProcAddress( FDLLHandle, 'GetDigitalOutputs' );
 
// Square Wave Generator:
  @FGetSquareWaveGenStatus := GetProcAddress( FDLLHandle, 'GetSquareWaveGenStatus' );
  @FGetSquareWaveGenFrequency := GetProcAddress( FDLLHandle, 'GetSquareWaveGenFrequency' );
  @FSetSquareWaveGenFrequency := GetProcAddress( FDLLHandle, 'SetSquareWaveGenFrequency' );
 
// Get information about the function generator:
  @FGetFunctionGenStatus := GetProcAddress( FDLLHandle, 'GetFunctionGenStatus' );
  @FGetFuncGenMaxAmplitude := GetProcAddress( FDLLHandle, 'GetFuncGenMaxAmplitude' );
 
// Control the Arbitrary Waveform Generator:
  @FGetFuncGenOutputOn := GetProcAddress( FDLLHandle, 'GetFuncGenOutputOn' );
  @FSetFuncGenOutputOn := GetProcAddress( FDLLHandle, 'SetFuncGenOutputOn' );
  @FGetFuncGenEnable := GetProcAddress( FDLLHandle, 'GetFuncGenEnable' );
  @FSetFuncGenEnable := GetProcAddress( FDLLHandle, 'SetFuncGenEnable' );
  @FGetFuncGenSignalType := GetProcAddress( FDLLHandle, 'GetFuncGenSignalType' );
  @FSetFuncGenSignalType := GetProcAddress( FDLLHandle, 'SetFuncGenSignalType' );
  @FSetFuncGenMode := GetProcAddress( FDLLHandle, 'SetFuncGenMode' );
  @FGetFuncGenMode := GetProcAddress( FDLLHandle, 'GetFuncGenMode' );
  @FGetFuncGenAmplitude := GetProcAddress( FDLLHandle, 'GetFuncGenAmplitude' );
  @FSetFuncGenAmplitude := GetProcAddress( FDLLHandle, 'SetFuncGenAmplitude' );
  @FGetFuncGenAmplitudeRange := GetProcAddress( FDLLHandle, 'GetFuncGenAmplitudeRange' );
  @FSetFuncGenAmplitudeRange := GetProcAddress( FDLLHandle, 'SetFuncGenAmplitudeRange' );
  @FGetFuncGenDCOffset := GetProcAddress( FDLLHandle, 'GetFuncGenDCOffset' );
  @FSetFuncGenDCOffset := GetProcAddress( FDLLHandle, 'SetFuncGenDCOffset' );
  @FGetFuncGenSymmetry := GetProcAddress( FDLLHandle, 'GetFuncGenSymmetry' );
  @FSetFuncGenSymmetry := GetProcAddress( FDLLHandle, 'SetFuncGenSymmetry' );
  @FGetFuncGenFrequency := GetProcAddress( FDLLHandle, 'GetFuncGenFrequency' );
  @FSetFuncGenFrequency := GetProcAddress( FDLLHandle, 'SetFuncGenFrequency' );
  @FSetFuncGenTrigSource := GetProcAddress( FDLLHandle, 'SetFuncGenTrigSource' );
  @FGetFuncGenTrigSource := GetProcAddress( FDLLHandle, 'GetFuncGenTrigSource' );
  @FFillFuncGenMemory := GetProcAddress( FDLLHandle, 'FillFuncGenMemory' );
  @FFuncGenBurst := GetProcAddress( FDLLHandle, 'FuncGenBurst' );
 
// Ohm measurements ( not available by default ):
  @FSetupOhmMeasurements := GetProcAddress( FDLLHandle, 'SetupOhmMeasurements' );
  @FGetOhmValues := GetProcAddress( FDLLHandle, 'GetOhmValues' );
 
// I2C routines:
  @FI2CWrite := GetProcAddress( FDLLHandle, 'I2CWrite' );
  @FI2CWriteNoStop := GetProcAddress( FDLLHandle, 'I2CWriteNoStop' );
  @FI2CRead := GetProcAddress( FDLLHandle, 'I2CRead' );
  @FI2CReadNoStop := GetProcAddress( FDLLHandle, 'I2CReadNoStop' );
  @FI2CGetSpeed := GetProcAddress( FDLLHandle, 'I2CGetSpeed' );
  @FI2CSetSpeed := GetProcAddress( FDLLHandle, 'I2CSetSpeed' );
 
// Handyscope HS2 Only:
  @FGetActiveHS2 := GetProcAddress( FDLLHandle, 'GetActiveHS2' );
  @FSetActiveHS2 := GetProcAddress( FDLLHandle, 'SetActiveHS2' );
  @FSetDAC1451 := GetProcAddress( FDLLHandle, 'SetDAC1451' );
  @FSetMotorOn := GetProcAddress( FDLLHandle, 'SetMotorOn' );
 
// Obsolete routines, use is deprecated:
  @FGetMaxSampleFrequency := GetProcAddress( FDLLHandle, 'GetMaxSampleFrequency' );
  @FStartMeasurement := GetProcAddress( FDLLHandle, 'StartMeasurement' );
  @FGetMeasurement := GetProcAddress( FDLLHandle, 'GetMeasurement' );
  @FGetMeasurementRaw := GetProcAddress( FDLLHandle, 'GetMeasurementRaw' );
  @FGetOneMeasurement := GetProcAddress( FDLLHandle, 'GetOneMeasurement' );
  @FGetOneMeasurementRaw := GetProcAddress( FDLLHandle, 'GetOneMeasurementRaw' );
  @FGetOneMeasurementRawCh := GetProcAddress( FDLLHandle, 'GetOneMeasurementRawCh' );
  @FADC_GetData := GetProcAddress( FDLLHandle, 'ADC_GetData' );
  @FADC_GetDataVolt := GetProcAddress( FDLLHandle, 'ADC_GetDataVolt' );
  @FGetSampleFrequency := GetProcAddress( FDLLHandle, 'GetSampleFrequency' );
  @FSetSampleFrequency := GetProcAddress( FDLLHandle, 'SetSampleFrequency' );
  @FGetTriggerTimeOut := GetProcAddress( FDLLHandle, 'GetTriggerTimeOut' );
  @FSetTriggerTimeOut := GetProcAddress( FDLLHandle, 'SetTriggerTimeOut' );

end; { RetrieveAllProcAddresses }

// Open / Close the instrument:
function TTiePieInstrument.InitInstrument( wAddress : Word ) : ERROR;
begin
  Result := FInitInstrument( wAddress );
end;

function TTiePieInstrument.ExitInstrument : ERROR;
begin
  Result := FExitInstrument;
end;

 
// Get information about the instrument:
function TTiePieInstrument.GetCalibrationDate( dwDate : PDWORD ) : ERROR;
begin
  Result := FGetCalibrationDate( dwDate );
end;

function TTiePieInstrument.GetSerialNumber( dwSerialNumber : PDWORD ) : ERROR;
begin
  Result := FGetSerialNumber( dwSerialNumber );
end;

function TTiePieInstrument.GetAvailableSensitivities( dSensitivities : PInfoArray ) : ERROR;
begin
  Result := FGetAvailableSensitivities( dSensitivities );
end;

function TTiePieInstrument.GetAvailableResolutions( dResolutions : PInfoArray ) : ERROR;
begin
  Result := FGetAvailableResolutions( dResolutions );
end;

function TTiePieInstrument.GetNrChannels( wValue : PWord ) : ERROR;
begin
  Result := FGetNrChannels( wValue );
end;

function TTiePieInstrument.GetMaxSampleFrequencyF : Double;
begin
  Result := FGetMaxSampleFrequencyF;
end;

function TTiePieInstrument.GetMaxRecordLength : DWORD;
begin
  Result := FGetMaxRecordLength;
end;

function TTiePieInstrument.GetDCLevelStatus : DWORD;
begin
  Result := FGetDCLevelStatus;
end;

 
// Measurement routines:
function TTiePieInstrument.ADC_Start : ERROR;
begin
  Result := FADC_Start;
end;

function TTiePieInstrument.ADC_Running : Word;
begin
  Result := FADC_Running;
end;

function TTiePieInstrument.ADC_Abort : ERROR;
begin
  Result := FADC_Abort;
end;

function TTiePieInstrument.ADC_ForceTrig : ERROR;
begin
  Result := FADC_ForceTrig;
end;

function TTiePieInstrument.ADC_Triggered : Word;
begin
  Result := FADC_Triggered;
end;

function TTiePieInstrument.ADC_Ready : Word;
begin
  Result := FADC_Ready;
end;

 
// Retrieve the measured data:
function TTiePieInstrument.ADC_GetDataCh( wCh : Word ; wChData : PTWArray ) : ERROR;
begin
  Result := FADC_GetDataCh( wCh , wChData );
end;

function TTiePieInstrument.ADC_GetDataVoltCh( wCh : Word ; dChData : PTDArray ) : ERROR;
begin
  Result := FADC_GetDataVoltCh( wCh , dChData );
end;

function TTiePieInstrument.GetDigitalInputValues( wValues : PTWArray ) : ERROR;
begin
  Result := FGetDigitalInputValues( wValues );
end;

function TTiePieInstrument.GetOneDigitalValue( dwIndex : DWORD ; wValue : PWord ) : ERROR;
begin
  Result := FGetOneDigitalValue( dwIndex , wValue );
end;

 
// Streaming measurements:
function TTiePieInstrument.SetDataReadyCallback( pAddress : TDataReady ) : ERROR;
begin
  Result := FSetDataReadyCallback( pAddress );
end;

function TTiePieInstrument.SetDataReadyEvent( hEvent : THandle ) : ERROR;
begin
  Result := FSetDataReadyEvent( hEvent );
end;

function TTiePieInstrument.SetTransferMode( dwMode : DWORD ) : ERROR;
begin
  Result := FSetTransferMode( dwMode );
end;

function TTiePieInstrument.GetTransferMode( dwMode : PDWORD ) : ERROR;
begin
  Result := FGetTransferMode( dwMode );
end;

 
// Control the input resolution in bits:
function TTiePieInstrument.SetResolution( byValue : Byte ) : ERROR;
begin
  Result := FSetResolution( byValue );
end;

function TTiePieInstrument.GetResolution( byValue : PByte ) : ERROR;
begin
  Result := FGetResolution( byValue );
end;

 
// Control the instrument configuration:
function TTiePieInstrument.SetInstrumentConfig( wMode : Word ) : ERROR;
begin
  Result := FSetInstrumentConfig( wMode );
end;

function TTiePieInstrument.GetInstrumentConfig( wMode : PWord ) : ERROR;
begin
  Result := FGetInstrumentConfig( wMode );
end;

 
// Control which channels are measured:
function TTiePieInstrument.GetMeasureMode( byMode : PByte ) : ERROR;
begin
  Result := FGetMeasureMode( byMode );
end;

function TTiePieInstrument.SetMeasureMode( byMode : Byte ) : ERROR;
begin
  Result := FSetMeasureMode( byMode );
end;

 
// Control the time base:
function TTiePieInstrument.GetRecordLength : DWORD;
begin
  Result := FGetRecordLength;
end;

function TTiePieInstrument.SetRecordLength( dwRecordLength : DWORD ) : ERROR;
begin
  Result := FSetRecordLength( dwRecordLength );
end;

function TTiePieInstrument.GetPostSamples : DWORD;
begin
  Result := FGetPostSamples;
end;

function TTiePieInstrument.SetPostSamples( dwPostSampleCount : DWORD ) : ERROR;
begin
  Result := FSetPostSamples( dwPostSampleCount );
end;

function TTiePieInstrument.GetSampleFrequencyF : Double;
begin
  Result := FGetSampleFrequencyF;
end;

function TTiePieInstrument.SetSampleFrequencyF( dFreq : PDouble ) : ERROR;
begin
  Result := FSetSampleFrequencyF( dFreq );
end;

function TTiePieInstrument.GetExternalClock( wMode : PWord ) : ERROR;
begin
  Result := FGetExternalClock( wMode );
end;

function TTiePieInstrument.SetExternalClock( wMode : Word ) : ERROR;
begin
  Result := FSetExternalClock( wMode );
end;

 
// Control the analog input channels:
function TTiePieInstrument.GetSensitivity( byCh : Byte ; dSensitivity : PDouble ) : ERROR;
begin
  Result := FGetSensitivity( byCh , dSensitivity );
end;

function TTiePieInstrument.SetSensitivity( byCh : Byte ; dSensitivity : PDouble ) : ERROR;
begin
  Result := FSetSensitivity( byCh , dSensitivity );
end;

function TTiePieInstrument.GetAutoRanging( byCh : Byte ; byMode : PByte ) : ERROR;
begin
  Result := FGetAutoRanging( byCh , byMode );
end;

function TTiePieInstrument.SetAutoRanging( byCh : Byte ; byMode : Byte ) : ERROR;
begin
  Result := FSetAutoRanging( byCh , byMode );
end;

function TTiePieInstrument.GetCoupling( byCh : Byte ; byMode : PByte ) : ERROR;
begin
  Result := FGetCoupling( byCh , byMode );
end;

function TTiePieInstrument.SetCoupling( byCh : Byte ; byMode : Byte ) : ERROR;
begin
  Result := FSetCoupling( byCh , byMode );
end;

function TTiePieInstrument.GetDcLevel( byCh : Byte ; dDcLevel : PDouble ) : ERROR;
begin
  Result := FGetDcLevel( byCh , dDcLevel );
end;

function TTiePieInstrument.SetDcLevel( byCh : Byte ; dDcLevel : Double ) : ERROR;
begin
  Result := FSetDcLevel( byCh , dDcLevel );
end;

 
// Control the trigger system:
function TTiePieInstrument.GetTriggerSource( byTrigSource : PByte ) : ERROR;
begin
  Result := FGetTriggerSource( byTrigSource );
end;

function TTiePieInstrument.SetTriggerSource( byTrigSource : Byte ) : ERROR;
begin
  Result := FSetTriggerSource( byTrigSource );
end;

function TTiePieInstrument.GetTriggerMode( byMode : PByte ) : ERROR;
begin
  Result := FGetTriggerMode( byMode );
end;

function TTiePieInstrument.SetTriggerMode( byMode : Byte ) : ERROR;
begin
  Result := FSetTriggerMode( byMode );
end;

function TTiePieInstrument.GetTriggerModeCh( byCh : Byte ; byMode : PByte ) : ERROR;
begin
  Result := FGetTriggerModeCh( byCh , byMode );
end;

function TTiePieInstrument.SetTriggerModeCh( byCh : Byte ; byMode : Byte ) : ERROR;
begin
  Result := FSetTriggerModeCh( byCh , byMode );
end;

function TTiePieInstrument.GetTriggerLevel( byCh : Byte ; dLevel : PDouble ) : ERROR;
begin
  Result := FGetTriggerLevel( byCh , dLevel );
end;

function TTiePieInstrument.SetTriggerLevel( byCh : Byte ; dLevel : Double ) : ERROR;
begin
  Result := FSetTriggerLevel( byCh , dLevel );
end;

function TTiePieInstrument.GetTriggerHys( byCh : Byte ; dHysteresis : PDouble ) : ERROR;
begin
  Result := FGetTriggerHys( byCh , dHysteresis );
end;

function TTiePieInstrument.SetTriggerHys( byCh : Byte ; dHysteresis : Double ) : ERROR;
begin
  Result := FSetTriggerHys( byCh , dHysteresis );
end;

function TTiePieInstrument.GetPXITriggerEnables( byEnables : PByte ) : ERROR;
begin
  Result := FGetPXITriggerEnables( byEnables );
end;

function TTiePieInstrument.SetPXITriggerEnables( byEnables : Byte ) : ERROR;
begin
  Result := FSetPXITriggerEnables( byEnables );
end;

function TTiePieInstrument.GetPXITriggerSlopes( bySlopes : PByte ) : ERROR;
begin
  Result := FGetPXITriggerSlopes( bySlopes );
end;

function TTiePieInstrument.SetPXITriggerSlopes( bySlopes : Byte ) : ERROR;
begin
  Result := FSetPXITriggerSlopes( bySlopes );
end;

 
// Control the digital outputs:
function TTiePieInstrument.SetDigitalOutputs( byValue : Byte ) : ERROR;
begin
  Result := FSetDigitalOutputs( byValue );
end;

function TTiePieInstrument.GetDigitalOutputs( byValue : PByte ) : ERROR;
begin
  Result := FGetDigitalOutputs( byValue );
end;

 
// Square Wave Generator:
function TTiePieInstrument.GetSquareWaveGenStatus : ERROR;
begin
  Result := FGetSquareWaveGenStatus;
end;

function TTiePieInstrument.GetSquareWaveGenFrequency : DWORD;
begin
  Result := FGetSquareWaveGenFrequency;
end;

function TTiePieInstrument.SetSquareWaveGenFrequency( dwFreq : PDWORD ) : ERROR;
begin
  Result := FSetSquareWaveGenFrequency( dwFreq );
end;

 
// Get information about the function generator:
function TTiePieInstrument.GetFunctionGenStatus : ERROR;
begin
  Result := FGetFunctionGenStatus;
end;

function TTiePieInstrument.GetFuncGenMaxAmplitude( dMaxAmplitude : PDouble ) : ERROR;
begin
  Result := FGetFuncGenMaxAmplitude( dMaxAmplitude );
end;

 
// Control the Arbitrary Waveform Generator:
function TTiePieInstrument.GetFuncGenOutputOn( wValue : PWord ) : ERROR;
begin
  Result := FGetFuncGenOutputOn( wValue );
end;

function TTiePieInstrument.SetFuncGenOutputOn( wValue : Word ) : ERROR;
begin
  Result := FSetFuncGenOutputOn( wValue );
end;

function TTiePieInstrument.GetFuncGenEnable( wValue : PWord ) : ERROR;
begin
  Result := FGetFuncGenEnable( wValue );
end;

function TTiePieInstrument.SetFuncGenEnable( wValue : Word ) : ERROR;
begin
  Result := FSetFuncGenEnable( wValue );
end;

function TTiePieInstrument.GetFuncGenSignalType( wValue : PWord ) : ERROR;
begin
  Result := FGetFuncGenSignalType( wValue );
end;

function TTiePieInstrument.SetFuncGenSignalType( wValue : Word ) : ERROR;
begin
  Result := FSetFuncGenSignalType( wValue );
end;

function TTiePieInstrument.SetFuncGenMode( dwMode : DWORD ) : ERROR;
begin
  Result := FSetFuncGenMode( dwMode );
end;

function TTiePieInstrument.GetFuncGenMode( dwMode : PDWORD ) : ERROR;
begin
  Result := FGetFuncGenMode( dwMode );
end;

function TTiePieInstrument.GetFuncGenAmplitude( dValue : PDouble ) : ERROR;
begin
  Result := FGetFuncGenAmplitude( dValue );
end;

function TTiePieInstrument.SetFuncGenAmplitude( dValue : Double ) : ERROR;
begin
  Result := FSetFuncGenAmplitude( dValue );
end;

function TTiePieInstrument.GetFuncGenAmplitudeRange( byValue : PByte ) : ERROR;
begin
  Result := FGetFuncGenAmplitudeRange( byValue );
end;

function TTiePieInstrument.SetFuncGenAmplitudeRange( byValue : Byte ) : ERROR;
begin
  Result := FSetFuncGenAmplitudeRange( byValue );
end;

function TTiePieInstrument.GetFuncGenDCOffset( dValue : PDouble ) : ERROR;
begin
  Result := FGetFuncGenDCOffset( dValue );
end;

function TTiePieInstrument.SetFuncGenDCOffset( dValue : Double ) : ERROR;
begin
  Result := FSetFuncGenDCOffset( dValue );
end;

function TTiePieInstrument.GetFuncGenSymmetry( dValue : PDouble ) : ERROR;
begin
  Result := FGetFuncGenSymmetry( dValue );
end;

function TTiePieInstrument.SetFuncGenSymmetry( dValue : Double ) : ERROR;
begin
  Result := FSetFuncGenSymmetry( dValue );
end;

function TTiePieInstrument.GetFuncGenFrequency( dValue : PDouble ) : ERROR;
begin
  Result := FGetFuncGenFrequency( dValue );
end;

function TTiePieInstrument.SetFuncGenFrequency( dValue : PDouble ) : ERROR;
begin
  Result := FSetFuncGenFrequency( dValue );
end;

function TTiePieInstrument.SetFuncGenTrigSource( byTrigSource : Byte ) : ERROR;
begin
  Result := FSetFuncGenTrigSource( byTrigSource );
end;

function TTiePieInstrument.GetFuncGenTrigSource( byTrigSource : PByte ) : ERROR;
begin
  Result := FGetFuncGenTrigSource( byTrigSource );
end;

function TTiePieInstrument.FillFuncGenMemory( dwSampleCount : DWORD ; FuncGenData : PTWArray ) : ERROR;
begin
  Result := FFillFuncGenMemory( dwSampleCount , FuncGenData );
end;

function TTiePieInstrument.FuncGenBurst( wNrPeriods : Word ) : ERROR;
begin
  Result := FFuncGenBurst( wNrPeriods );
end;

 
// Ohm measurements ( not available by default ):
function TTiePieInstrument.SetupOhmMeasurements( wMode : Word ) : ERROR;
begin
  Result := FSetupOhmMeasurements( wMode );
end;

function TTiePieInstrument.GetOhmValues( dValue1 : PDouble ; dValue2 : PDouble ) : ERROR;
begin
  Result := FGetOhmValues( dValue1 , dValue2 );
end;

 
// I2C routines:
function TTiePieInstrument.I2CWrite( dwAddress : DWORD ; pBuf : pointer ; dwSize : DWORD ) : ERROR;
begin
  Result := FI2CWrite( dwAddress , pBuf , dwSize );
end;

function TTiePieInstrument.I2CWriteNoStop( dwAddress : DWORD ; pBuf : pointer ; dwSize : DWORD ) : ERROR;
begin
  Result := FI2CWriteNoStop( dwAddress , pBuf , dwSize );
end;

function TTiePieInstrument.I2CRead( dwAddress : DWORD ; pBuf : pointer ; dwSize : DWORD ) : ERROR;
begin
  Result := FI2CRead( dwAddress , pBuf , dwSize );
end;

function TTiePieInstrument.I2CReadNoStop( dwAddress : DWORD ; pBuf : pointer ; dwSize : DWORD ) : ERROR;
begin
  Result := FI2CReadNoStop( dwAddress , pBuf , dwSize );
end;

function TTiePieInstrument.I2CGetSpeed( dwSpeed : PDWORD ) : ERROR;
begin
  Result := FI2CGetSpeed( dwSpeed );
end;

function TTiePieInstrument.I2CSetSpeed( dwSpeed : PDWORD ) : ERROR;
begin
  Result := FI2CSetSpeed( dwSpeed );
end;

 
// Handyscope HS2 Only:
function TTiePieInstrument.GetActiveHS2( byActiveHS2 : PByte ) : ERROR;
begin
  Result := FGetActiveHS2( byActiveHS2 );
end;

function TTiePieInstrument.SetActiveHS2( byActiveHS2 : Byte ) : ERROR;
begin
  Result := FSetActiveHS2( byActiveHS2 );
end;

function TTiePieInstrument.SetDAC1451( dMotor1 : Double ; dMotor2 : Double ) : ERROR;
begin
  Result := FSetDAC1451( dMotor1 , dMotor2 );
end;

function TTiePieInstrument.SetMotorOn( byMotor1 : Byte ; byMotor2 : Byte ) : ERROR;
begin
  Result := FSetMotorOn( byMotor1 , byMotor2 );
end;

 
// Obsolete routines, use is deprecated:
function TTiePieInstrument.GetMaxSampleFrequency : DWORD;
begin
  Result := FGetMaxSampleFrequency;
end;

function TTiePieInstrument.StartMeasurement : ERROR;
begin
  Result := FStartMeasurement;
end;

function TTiePieInstrument.GetMeasurement( dCh1 : PTDArray ; dCh2 : PTDArray ) : ERROR;
begin
  Result := FGetMeasurement( dCh1 , dCh2 );
end;

function TTiePieInstrument.GetMeasurementRaw( wCh1 : PTWArray ; wCh2 : PTWArray ) : ERROR;
begin
  Result := FGetMeasurementRaw( wCh1 , wCh2 );
end;

function TTiePieInstrument.GetOneMeasurement( dwIndex : DWORD ; dCh1 : PDouble ; dCh2 : PDouble ) : ERROR;
begin
  Result := FGetOneMeasurement( dwIndex , dCh1 , dCh2 );
end;

function TTiePieInstrument.GetOneMeasurementRaw( dwIndex : DWORD ; wCh1 : PWord ; wCh2 : PWord ) : ERROR;
begin
  Result := FGetOneMeasurementRaw( dwIndex , wCh1 , wCh2 );
end;

function TTiePieInstrument.GetOneMeasurementRawCh( wCh : Word ; dwIndex : DWORD ; wChData : PWord ) : ERROR;
begin
  Result := FGetOneMeasurementRawCh( wCh , dwIndex , wChData );
end;

function TTiePieInstrument.ADC_GetData( wCh1 : PTWArray ; wCh2 : PTWArray ) : ERROR;
begin
  Result := FADC_GetData( wCh1 , wCh2 );
end;

function TTiePieInstrument.ADC_GetDataVolt( dCh1 : PTDArray ; dCh2 : PTDArray ) : ERROR;
begin
  Result := FADC_GetDataVolt( dCh1 , dCh2 );
end;

function TTiePieInstrument.GetSampleFrequency : DWORD;
begin
  Result := FGetSampleFrequency;
end;

function TTiePieInstrument.SetSampleFrequency( dwFreq : PDWORD ) : ERROR;
begin
  Result := FSetSampleFrequency( dwFreq );
end;

function TTiePieInstrument.GetTriggerTimeOut : DWORD;
begin
  Result := FGetTriggerTimeOut;
end;

function TTiePieInstrument.SetTriggerTimeOut( dwTimeout : DWORD ) : ERROR;
begin
  Result := FSetTriggerTimeOut( dwTimeout );
end;




end.

